Summary:      Utility for IPMI control
Name:         ipmitool
Version:      1.8.19
Release:      5%{?dist}

%global       urlversion  %(sed 's/\\./\\_/g' <<< %{version})

License:      BSD
URL:          https://github.com/%{name}/%{name}
Source0:      https://github.com/%{name}/%{name}/archive/refs/tags/IPMITOOL_%{urlversion}.tar.gz
Source1:      openipmi-ipmievd.sysconf
Source2:      ipmievd.service
Source3:      set-bmc-url.sh
# Download from https://www.iana.org/assignments/enterprise-numbers/enterprise-numbers
Source4:      enterprise-numbers

Patch3000:    CVE-2011-4339-OpenIPMI.patch

BuildRequires: automake autoconf libtool systemd
BuildRequires: openssl-devel readline-devel ncurses-devel
%{?systemd_requires}
Provides: OpenIPMI-tools = 2.0.14-3


%description
ipmitool is a utility for managing and configuring devices that support
the Intelligent Platform Management Interface.  IPMI is an open standard
for monitoring, logging, recovery, inventory, and control of hardware
that is implemented independent of the main CPU, BIOS, and OS.  The
service processor (or Baseboard Management Controller, BMC) is the brain
behind platform management and its primary purpose is to handle the
autonomous sensor monitoring and event logging features.

The ipmitool program provides a simple command-line interface to this BMC.
It features the ability to read the sensor data repository (SDR) and print
sensor values, display the contents of the System Event Log (SEL), print
Field Replaceable Unit (FRU) inventory information, read and set LAN
configuration parameters, and perform remote chassis power control.


%package -n ipmievd
Summary: IPMI event daemon for sending events to syslog
Requires: %{name} = %{version}-%{release}
%{?systemd_requires}

%description -n ipmievd
ipmievd is a daemon which will listen for events from the BMC that are
being  sent to the SEL and also log those messages to syslog.


%package -n bmc-snmp-proxy
Summary: Reconfigure SNMP to include host SNMP agent within BMC
Requires: net-snmp, exchange-bmc-os-info
BuildArch: noarch

%description -n bmc-snmp-proxy
Given a host with BMC, this package would extend system configuration
of net-snmp to include redirections to BMC based SNMP.


%package -n exchange-bmc-os-info
Summary: Let OS and BMC exchange info
Requires: hostname
Requires: %{name} = %{version}-%{release}
BuildArch: noarch
%{?systemd_requires}


%description -n exchange-bmc-os-info
Given a host with BMC, this package would pass the hostname &
OS information to the BMC and also capture the BMC ip info
for the host OS to use.


%prep
%autosetup -n %{name}-IPMITOOL_%{urlversion} -p1


%build
aclocal
libtoolize --automake --copy
autoheader
automake --foreign --add-missing --copy
aclocal
autoconf
automake --foreign

install -Dm 644 %{SOURCE4} .
%configure \
     --disable-dependency-tracking \
     --disable-intf-free \
     --enable-file-security \
     --enable-intf-usb
%make_build

%install
%make_install

install -Dpm644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/ipmievd
install -Dpm644 %{SOURCE2} %{buildroot}%{_unitdir}/ipmievd.service
install -Dm644 %{SOURCE3} %{buildroot}%{_sysconfdir}/profile.d/set-bmc-url.sh
install -Dm755 contrib/exchange-bmc-os-info.init.redhat %{buildroot}%{_libexecdir}/exchange-bmc-os-info
install -Dm644 contrib/exchange-bmc-os-info.service.redhat %{buildroot}%{_unitdir}/exchange-bmc-os-info.service
install -Dm644 contrib/exchange-bmc-os-info.sysconf %{buildroot}%{_sysconfdir}/sysconfig/exchange-bmc-os-info
install -Dm644 contrib/bmc-snmp-proxy.sysconf %{buildroot}%{_sysconfdir}/sysconfig/bmc-snmp-proxy
install -Dm644 contrib/bmc-snmp-proxy.service %{buildroot}%{_unitdir}/bmc-snmp-proxy.service
install -Dm755 contrib/bmc-snmp-proxy         %{buildroot}%{_libexecdir}/bmc-snmp-proxy

%post -n ipmievd
%systemd_post ipmievd.service

%preun -n ipmievd
%systemd_preun ipmievd.service

%postun -n ipmievd
%systemd_postun_with_restart ipmievd.service

%post -n exchange-bmc-os-info
%systemd_post exchange-bmc-os-info.service

%preun -n exchange-bmc-os-info
%systemd_preun exchange-bmc-os-info.service

%postun -n exchange-bmc-os-info
%systemd_postun_with_restart exchange-bmc-os-info.service


%files
%license COPYING AUTHORS
%doc %{_datadir}/doc/ipmitool
%{_bindir}/ipmitool
%{_datadir}/ipmitool
%{_mandir}/man1/ipmitool.1*
%{_datadir}/misc/enterprise-numbers


%files -n ipmievd
%config(noreplace) %{_sysconfdir}/sysconfig/ipmievd
%{_unitdir}/ipmievd.service
%{_sbindir}/ipmievd
%{_mandir}/man8/ipmievd.8*


%files -n exchange-bmc-os-info
%config(noreplace) %{_sysconfdir}/sysconfig/exchange-bmc-os-info
%{_sysconfdir}/profile.d/set-bmc-url.sh
%{_unitdir}/exchange-bmc-os-info.service
%{_libexecdir}/exchange-bmc-os-info


%files -n bmc-snmp-proxy
%config(noreplace) %{_sysconfdir}/sysconfig/bmc-snmp-proxy
%{_unitdir}/bmc-snmp-proxy.service
%{_libexecdir}/bmc-snmp-proxy

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.19-5
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Jun 28 2023 kianli <kianli@tencent.com> - 1.8.19-4
- Add iana enterprise numbers

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.19-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.19-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Sep 1 2022 cunshunxia <cunshunxia@tencent.com> - 1.8.19-1
- initial build
